==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/UpdateUISchema.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.UISchemaObject;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * The updated request body properties
 */
@ApiModel(description = "The updated request body properties")
@JsonPropertyOrder({ UpdateUISchema.JSON_PROPERTY_UI_SCHEMA })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class UpdateUISchema implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_UI_SCHEMA = "uiSchema";
    private UISchemaObject uiSchema;

    public UpdateUISchema() {
    }

    public UpdateUISchema uiSchema(UISchemaObject uiSchema) {

        this.uiSchema = uiSchema;
        return this;
    }

    /**
     * Get uiSchema
     *
     * @return uiSchema
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_UI_SCHEMA)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public UISchemaObject getUiSchema() {
        return uiSchema;
    }

    @JsonProperty(JSON_PROPERTY_UI_SCHEMA)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setUiSchema(UISchemaObject uiSchema) {
        this.uiSchema = uiSchema;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UpdateUISchema updateUISchema = (UpdateUISchema) o;
        return Objects.equals(this.uiSchema, updateUISchema.uiSchema);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(uiSchema);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UpdateUISchema {\n");
        sb.append("    uiSchema: ").append(toIndentedString(uiSchema)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/UpdateUISchema.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.UISchemaObject;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * The updated request body properties
 */
@ApiModel(description = "The updated request body properties")
@JsonPropertyOrder({ UpdateUISchema.JSON_PROPERTY_UI_SCHEMA })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class UpdateUISchema implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_UI_SCHEMA = "uiSchema";
    private UISchemaObject uiSchema;

    public UpdateUISchema() {
    }

    public UpdateUISchema uiSchema(UISchemaObject uiSchema) {

        this.uiSchema = uiSchema;
        return this;
    }

    /**
     * Get uiSchema
     *
     * @return uiSchema
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_UI_SCHEMA)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public UISchemaObject getUiSchema() {
        return uiSchema;
    }

    @JsonProperty(JSON_PROPERTY_UI_SCHEMA)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setUiSchema(UISchemaObject uiSchema) {
        this.uiSchema = uiSchema;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UpdateUISchema updateUISchema = (UpdateUISchema) o;
        return Objects.equals(this.uiSchema, updateUISchema.uiSchema);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(uiSchema);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UpdateUISchema {\n");
        sb.append("    uiSchema: ").append(toIndentedString(uiSchema)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
